@@ -399,3 +399,6 @@ def nse_get_fno_lot_sizes(symbol="all",mode="list"):
         else:
             payload = payload[(payload.iloc[:, 1] == symbol.upper())]
             return payload
+
+def whoistheboss():
+    return "subhash"
